# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.workflowexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_enum__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/stigmer/agentic/workflowexecution/v1/io.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x31\x61i/stigmer/agentic/workflowexecution/v1/api.proto\x1a\x32\x61i/stigmer/agentic/workflowexecution/v1/enum.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"3\n\x13WorkflowExecutionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"*\n\nWorkflowId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x8e\x01\n\x15WorkflowExecutionList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12T\n\x07\x65ntries\x18\x02 \x03(\x0b\x32:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionR\x07\x65ntries\"\xbe\x01\n\x1dListWorkflowExecutionsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12M\n\x05phase\x18\x03 \x01(\x0e\x32\x37.ai.stigmer.agentic.workflowexecution.v1.ExecutionPhaseR\x05phase\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\"\x8e\x01\n\'ListWorkflowExecutionsByWorkflowRequest\x12\'\n\x0bworkflow_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nworkflowId\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xb2\x01\n\"WorkflowExecutionUpdateStatusInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12`\n\x06status\x18\x02 \x01(\x0b\x32@.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionStatusB\x06\xbaH\x03\xc8\x01\x01R\x06status\"\xe8\x01\n\x1bSubmitWorkflowApprovalInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12)\n\x0ctool_call_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ntoolCallId\x12X\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ApprovalActionB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\x06\x61\x63tion\x12\x18\n\x07\x63omment\x18\x04 \x01(\tR\x07\x63omment\"N\n!SubscribeWorkflowExecutionRequest\x12)\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x65xecutionId\"\xa6\x02\n\x17WorkflowExecutionUpdate\x12\x66\n\x0bupdate_type\x18\x01 \x01(\x0e\x32;.ai.stigmer.agentic.workflowexecution.v1.WorkflowUpdateTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\nupdateType\x12X\n\texecution\x18\x02 \x01(\x0b\x32:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionR\texecution\x12I\n\x04task\x18\x03 \x01(\x0b\x32\x35.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskR\x04task\"O\n\x1c\x43\x61ncelWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"R\n\x1fTerminateWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"P\n\x1dRecoverWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"N\n\x1bPauseWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"7\n\x1cResumeWorkflowExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\"\xc3\x01\n\x0fSendSignalInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bsignal_name\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nsignalName\x12\x31\n\x07payload\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07payload\x12\'\n\x0fidempotency_key\x18\x04 \x01(\tR\x0eidempotencyKey*\xf3\x01\n\x12WorkflowUpdateType\x12$\n workflow_update_type_unspecified\x10\x00\x12\x1c\n\x18wf_update_status_changed\x10\x01\x12\x1a\n\x16wf_update_task_started\x10\x02\x12\x1c\n\x18wf_update_task_completed\x10\x03\x12\x19\n\x15wf_update_task_failed\x10\x04\x12!\n\x1dwf_update_execution_completed\x10\x05\x12!\n\x1dwf_update_execution_cancelled\x10\x06\x42\xf7\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\007IoProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTIONID'].fields_by_name['value']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWID'].fields_by_name['value']._loaded_options = None
  _globals['_WORKFLOWID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['tool_call_id']._loaded_options = None
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['tool_call_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['action']._loaded_options = None
  _globals['_SUBMITWORKFLOWAPPROVALINPUT'].fields_by_name['action']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWEXECUTIONUPDATE'].fields_by_name['update_type']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONUPDATE'].fields_by_name['update_type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_CANCELWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_CANCELWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SENDSIGNALINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_SENDSIGNALINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SENDSIGNALINPUT'].fields_by_name['signal_name']._loaded_options = None
  _globals['_SENDSIGNALINPUT'].fields_by_name['signal_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWUPDATETYPE']._serialized_start=2260
  _globals['_WORKFLOWUPDATETYPE']._serialized_end=2503
  _globals['_WORKFLOWEXECUTIONID']._serialized_start=304
  _globals['_WORKFLOWEXECUTIONID']._serialized_end=355
  _globals['_WORKFLOWID']._serialized_start=357
  _globals['_WORKFLOWID']._serialized_end=399
  _globals['_WORKFLOWEXECUTIONLIST']._serialized_start=402
  _globals['_WORKFLOWEXECUTIONLIST']._serialized_end=544
  _globals['_LISTWORKFLOWEXECUTIONSREQUEST']._serialized_start=547
  _globals['_LISTWORKFLOWEXECUTIONSREQUEST']._serialized_end=737
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST']._serialized_start=740
  _globals['_LISTWORKFLOWEXECUTIONSBYWORKFLOWREQUEST']._serialized_end=882
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT']._serialized_start=885
  _globals['_WORKFLOWEXECUTIONUPDATESTATUSINPUT']._serialized_end=1063
  _globals['_SUBMITWORKFLOWAPPROVALINPUT']._serialized_start=1066
  _globals['_SUBMITWORKFLOWAPPROVALINPUT']._serialized_end=1298
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST']._serialized_start=1300
  _globals['_SUBSCRIBEWORKFLOWEXECUTIONREQUEST']._serialized_end=1378
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_start=1381
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_end=1675
  _globals['_CANCELWORKFLOWEXECUTIONINPUT']._serialized_start=1677
  _globals['_CANCELWORKFLOWEXECUTIONINPUT']._serialized_end=1756
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT']._serialized_start=1758
  _globals['_TERMINATEWORKFLOWEXECUTIONINPUT']._serialized_end=1840
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT']._serialized_start=1842
  _globals['_RECOVERWORKFLOWEXECUTIONINPUT']._serialized_end=1922
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT']._serialized_start=1924
  _globals['_PAUSEWORKFLOWEXECUTIONINPUT']._serialized_end=2002
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT']._serialized_start=2004
  _globals['_RESUMEWORKFLOWEXECUTIONINPUT']._serialized_end=2059
  _globals['_SENDSIGNALINPUT']._serialized_start=2062
  _globals['_SENDSIGNALINPUT']._serialized_end=2257
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/iam/iampolicy/v1/spec.proto\x12\x1b\x61i.stigmer.iam.iampolicy.v1\x1a\x1b\x62uf/validate/validate.proto\"\xdd\x01\n\rIamPolicySpec\x12Q\n\tprincipal\x18\x01 \x01(\x0b\x32+.ai.stigmer.iam.iampolicy.v1.ApiResourceRefB\x06\xbaH\x03\xc8\x01\x01R\tprincipal\x12O\n\x08resource\x18\x02 \x01(\x0b\x32+.ai.stigmer.iam.iampolicy.v1.ApiResourceRefB\x06\xbaH\x03\xc8\x01\x01R\x08resource\x12(\n\x08relation\x18\x03 \x01(\tB\x0c\xbaH\tr\x04\x10\x01\x18@\xc8\x01\x01R\x08relation\"x\n\x0e\x41piResourceRef\x12!\n\x04kind\x18\x01 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\x80\x02\xc8\x01\x01R\x04kind\x12\x1d\n\x02id\x18\x02 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\x80\x02\xc8\x01\x01R\x02id\x12$\n\x08relation\x18\x03 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x02R\x08relationB\xbd\x01\n\x1f\x63om.ai.stigmer.iam.iampolicy.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SII\xaa\x02\x1b\x41i.Stigmer.Iam.Iampolicy.V1\xca\x02\x1b\x41i\\Stigmer\\Iam\\Iampolicy\\V1\xe2\x02\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Iam::Iampolicy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.iam.iampolicy.v1B\tSpecProtoP\001\242\002\004ASII\252\002\033Ai.Stigmer.Iam.Iampolicy.V1\312\002\033Ai\\Stigmer\\Iam\\Iampolicy\\V1\342\002\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Iam::Iampolicy::V1'
  _globals['_IAMPOLICYSPEC'].fields_by_name['principal']._loaded_options = None
  _globals['_IAMPOLICYSPEC'].fields_by_name['principal']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IAMPOLICYSPEC'].fields_by_name['resource']._loaded_options = None
  _globals['_IAMPOLICYSPEC'].fields_by_name['resource']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IAMPOLICYSPEC'].fields_by_name['relation']._loaded_options = None
  _globals['_IAMPOLICYSPEC'].fields_by_name['relation']._serialized_options = b'\272H\tr\004\020\001\030@\310\001\001'
  _globals['_APIRESOURCEREF'].fields_by_name['kind']._loaded_options = None
  _globals['_APIRESOURCEREF'].fields_by_name['kind']._serialized_options = b'\272H\nr\005\020\001\030\200\002\310\001\001'
  _globals['_APIRESOURCEREF'].fields_by_name['id']._loaded_options = None
  _globals['_APIRESOURCEREF'].fields_by_name['id']._serialized_options = b'\272H\nr\005\020\001\030\200\002\310\001\001'
  _globals['_APIRESOURCEREF'].fields_by_name['relation']._loaded_options = None
  _globals['_APIRESOURCEREF'].fields_by_name['relation']._serialized_options = b'\272H\005r\003\030\200\002'
  _globals['_IAMPOLICYSPEC']._serialized_start=101
  _globals['_IAMPOLICYSPEC']._serialized_end=322
  _globals['_APIRESOURCEREF']._serialized_start=324
  _globals['_APIRESOURCEREF']._serialized_end=444
# @@protoc_insertion_point(module_scope)



from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RaiseTaskConfig(_message.Message):
    __slots__ = ("error", "message")
    ERROR_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    error: str
    message: str
    def __init__(self, error: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.platform.github.v1 import service_pb2 as ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2


class GitHubServiceStub(object):
    """GitHubService provides OAuth integration with GitHub.

    This is a platform utility service — not a domain resource.
    It enables the web console (and SDK consumers) to connect a user's
    GitHub account via OAuth, then browse and select repositories
    for workspace configuration.

    The service handles the server-side OAuth code exchange (protecting
    the client_secret) and provides the authorize URL so the frontend
    does not need to know the client_id or redirect_uri.

    Tokens are ephemeral — they are returned to the caller and never
    persisted by the backend.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getOAuthAuthorizeUrl = channel.unary_unary(
                '/ai.stigmer.platform.github.v1.GitHubService/getOAuthAuthorizeUrl',
                request_serializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.GetOAuthAuthorizeUrlRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.GetOAuthAuthorizeUrlResponse.FromString,
                _registered_method=True)
        self.exchangeOAuthCode = channel.unary_unary(
                '/ai.stigmer.platform.github.v1.GitHubService/exchangeOAuthCode',
                request_serializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.ExchangeOAuthCodeRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.ExchangeOAuthCodeResponse.FromString,
                _registered_method=True)


class GitHubServiceServicer(object):
    """GitHubService provides OAuth integration with GitHub.

    This is a platform utility service — not a domain resource.
    It enables the web console (and SDK consumers) to connect a user's
    GitHub account via OAuth, then browse and select repositories
    for workspace configuration.

    The service handles the server-side OAuth code exchange (protecting
    the client_secret) and provides the authorize URL so the frontend
    does not need to know the client_id or redirect_uri.

    Tokens are ephemeral — they are returned to the caller and never
    persisted by the backend.
    """

    def getOAuthAuthorizeUrl(self, request, context):
        """Returns the GitHub OAuth authorize URL for initiating the OAuth flow.

        The backend constructs the URL with the registered client_id, requested
        scopes, and a random state parameter for CSRF protection. The frontend
        redirects the user to this URL, and GitHub redirects back to the
        provided redirect_uri with an authorization code.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def exchangeOAuthCode(self, request, context):
        """Exchanges a GitHub OAuth authorization code for an access token.

        The frontend calls this after receiving the authorization code from
        GitHub's OAuth redirect. The backend makes the token exchange request
        to GitHub using the client_secret (which must never be exposed to
        the frontend).

        The returned access_token is NOT stored by the backend. The frontend
        is responsible for persisting it (e.g., in localStorage) and including
        it in subsequent requests that need GitHub access.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GitHubServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getOAuthAuthorizeUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.getOAuthAuthorizeUrl,
                    request_deserializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.GetOAuthAuthorizeUrlRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.GetOAuthAuthorizeUrlResponse.SerializeToString,
            ),
            'exchangeOAuthCode': grpc.unary_unary_rpc_method_handler(
                    servicer.exchangeOAuthCode,
                    request_deserializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.ExchangeOAuthCodeRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.ExchangeOAuthCodeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.platform.github.v1.GitHubService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.platform.github.v1.GitHubService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GitHubService(object):
    """GitHubService provides OAuth integration with GitHub.

    This is a platform utility service — not a domain resource.
    It enables the web console (and SDK consumers) to connect a user's
    GitHub account via OAuth, then browse and select repositories
    for workspace configuration.

    The service handles the server-side OAuth code exchange (protecting
    the client_secret) and provides the authorize URL so the frontend
    does not need to know the client_id or redirect_uri.

    Tokens are ephemeral — they are returned to the caller and never
    persisted by the backend.
    """

    @staticmethod
    def getOAuthAuthorizeUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.platform.github.v1.GitHubService/getOAuthAuthorizeUrl',
            ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.GetOAuthAuthorizeUrlRequest.SerializeToString,
            ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.GetOAuthAuthorizeUrlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def exchangeOAuthCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.platform.github.v1.GitHubService/exchangeOAuthCode',
            ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.ExchangeOAuthCodeRequest.SerializeToString,
            ai_dot_stigmer_dot_platform_dot_github_dot_v1_dot_service__pb2.ExchangeOAuthCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_approval__pb2
from ai.stigmer.agentic.workflowexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.workflowexecution.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ai/stigmer/agentic/workflowexecution/v1/api.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a\x33\x61i/stigmer/agentic/agentexecution/v1/approval.proto\x1a\x32\x61i/stigmer/agentic/workflowexecution/v1/enum.proto\x1a\x32\x61i/stigmer/agentic/workflowexecution/v1/spec.proto\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x87\x03\n\x11WorkflowExecution\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15\x61gentic.stigmer.ai/v1R\napiVersion\x12,\n\x04kind\x18\x02 \x01(\tB\x18\xbaH\x15r\x13\n\x11WorkflowExecutionR\x04kind\x12W\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12R\n\x04spec\x18\x04 \x01(\x0b\x32>.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionSpecR\x04spec\x12X\n\x06status\x18\x05 \x01(\x0b\x32@.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionStatusR\x06status\"\xa6\x04\n\x17WorkflowExecutionStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12W\n\x05phase\x18\x01 \x01(\x0e\x32\x37.ai.stigmer.agentic.workflowexecution.v1.ExecutionPhaseB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x05phase\x12K\n\x05tasks\x18\x02 \x03(\x0b\x32\x35.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskR\x05tasks\x12/\n\x06output\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12\x14\n\x05\x65rror\x18\x04 \x01(\tR\x05\x65rror\x12\x1d\n\nstarted_at\x18\x05 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x06 \x01(\tR\x0b\x63ompletedAt\x12\x30\n\x14temporal_workflow_id\x18\x07 \x01(\tR\x12temporalWorkflowId\x12\x62\n\x11pending_approvals\x18\t \x03(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.PendingApprovalR\x10pendingApprovals\"\xf2\x03\n\x0cWorkflowTask\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\x12\x1b\n\ttask_name\x18\x02 \x01(\tR\x08taskName\x12`\n\ttask_type\x18\x03 \x01(\x0e\x32\x39.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x08taskType\x12-\n\x05input\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x05input\x12/\n\x06output\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12]\n\x06status\x18\x06 \x01(\x0e\x32;.ai.stigmer.agentic.workflowexecution.v1.WorkflowTaskStatusB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x06status\x12\x1d\n\nstarted_at\x18\x07 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x08 \x01(\tR\x0b\x63ompletedAt\x12\x14\n\x05\x65rror\x18\t \x01(\tR\x05\x65rror\x12\x33\n\x08metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadataB\xf8\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\010ApiProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTION'].fields_by_name['api_version']._loaded_options = None
  _globals['_WORKFLOWEXECUTION'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025agentic.stigmer.ai/v1'
  _globals['_WORKFLOWEXECUTION'].fields_by_name['kind']._loaded_options = None
  _globals['_WORKFLOWEXECUTION'].fields_by_name['kind']._serialized_options = b'\272H\025r\023\n\021WorkflowExecution'
  _globals['_WORKFLOWEXECUTION'].fields_by_name['metadata']._loaded_options = None
  _globals['_WORKFLOWEXECUTION'].fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WORKFLOWEXECUTIONSTATUS'].fields_by_name['phase']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONSTATUS'].fields_by_name['phase']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_WORKFLOWTASK'].fields_by_name['task_type']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['task_type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_WORKFLOWTASK'].fields_by_name['status']._loaded_options = None
  _globals['_WORKFLOWTASK'].fields_by_name['status']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_WORKFLOWEXECUTION']._serialized_start=403
  _globals['_WORKFLOWEXECUTION']._serialized_end=794
  _globals['_WORKFLOWEXECUTIONSTATUS']._serialized_start=797
  _globals['_WORKFLOWEXECUTIONSTATUS']._serialized_end=1347
  _globals['_WORKFLOWTASK']._serialized_start=1350
  _globals['_WORKFLOWTASK']._serialized_end=1848
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IamPolicySpec(_message.Message):
    __slots__ = ("principal", "resource", "relation")
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    principal: ApiResourceRef
    resource: ApiResourceRef
    relation: str
    def __init__(self, principal: _Optional[_Union[ApiResourceRef, _Mapping]] = ..., resource: _Optional[_Union[ApiResourceRef, _Mapping]] = ..., relation: _Optional[str] = ...) -> None: ...

class ApiResourceRef(_message.Message):
    __slots__ = ("kind", "id", "relation")
    KIND_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    kind: str
    id: str
    relation: str
    def __init__(self, kind: _Optional[str] = ..., id: _Optional[str] = ..., relation: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/environment/v1/spec.proto\x12!ai.stigmer.agentic.environment.v1\"\xf3\x01\n\x0f\x45nvironmentSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12P\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32<.ai.stigmer.agentic.environment.v1.EnvironmentSpec.DataEntryR\x04\x64\x61ta\x1al\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.ai.stigmer.agentic.environment.v1.EnvironmentValueR\x05value:\x02\x38\x01\"g\n\x10\x45nvironmentValue\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x1b\n\tis_secret\x18\x02 \x01(\x08R\x08isSecret\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scriptionB\xdb\x01\n%com.ai.stigmer.agentic.environment.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\tSpecProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._loaded_options = None
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENTSPEC']._serialized_start=84
  _globals['_ENVIRONMENTSPEC']._serialized_end=327
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._serialized_start=219
  _globals['_ENVIRONMENTSPEC_DATAENTRY']._serialized_end=327
  _globals['_ENVIRONMENTVALUE']._serialized_start=329
  _globals['_ENVIRONMENTVALUE']._serialized_end=432
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf.internal import python_message as _python_message
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Edition(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EDITION_UNKNOWN: _ClassVar[Edition]
    EDITION_LEGACY: _ClassVar[Edition]
    EDITION_PROTO2: _ClassVar[Edition]
    EDITION_PROTO3: _ClassVar[Edition]
    EDITION_2023: _ClassVar[Edition]
    EDITION_2024: _ClassVar[Edition]
    EDITION_1_TEST_ONLY: _ClassVar[Edition]
    EDITION_2_TEST_ONLY: _ClassVar[Edition]
    EDITION_99997_TEST_ONLY: _ClassVar[Edition]
    EDITION_99998_TEST_ONLY: _ClassVar[Edition]
    EDITION_99999_TEST_ONLY: _ClassVar[Edition]
    EDITION_MAX: _ClassVar[Edition]
EDITION_UNKNOWN: Edition
EDITION_LEGACY: Edition
EDITION_PROTO2: Edition
EDITION_PROTO3: Edition
EDITION_2023: Edition
EDITION_2024: Edition
EDITION_1_TEST_ONLY: Edition
EDITION_2_TEST_ONLY: Edition
EDITION_99997_TEST_ONLY: Edition
EDITION_99998_TEST_ONLY: Edition
EDITION_99999_TEST_ONLY: Edition
EDITION_MAX: Edition

class FileDescriptorSet(_message.Message):
    __slots__ = ("file",)
    Extensions: _python_message._ExtensionDict
    FILE_FIELD_NUMBER: _ClassVar[int]
    file: _containers.RepeatedCompositeFieldContainer[FileDescriptorProto]
    def __init__(self, file: _Optional[_Iterable[_Union[FileDescriptorProto, _Mapping]]] = ...) -> None: ...

class FileDescriptorProto(_message.Message):
    __slots__ = ("name", "package", "dependency", "public_dependency", "weak_dependency", "message_type", "enum_type", "service", "extension", "options", "source_code_info", "syntax", "edition")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_FIELD_NUMBER: _ClassVar[int]
    DEPENDENCY_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_DEPENDENCY_FIELD_NUMBER: _ClassVar[int]
    WEAK_DEPENDENCY_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENUM_TYPE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CODE_INFO_FIELD_NUMBER: _ClassVar[int]
    SYNTAX_FIELD_NUMBER: _ClassVar[int]
    EDITION_FIELD_NUMBER: _ClassVar[int]
    name: str
    package: str
    dependency: _containers.RepeatedScalarFieldContainer[str]
    public_dependency: _containers.RepeatedScalarFieldContainer[int]
    weak_dependency: _containers.RepeatedScalarFieldContainer[int]
    message_type: _containers.RepeatedCompositeFieldContainer[DescriptorProto]
    enum_type: _containers.RepeatedCompositeFieldContainer[EnumDescriptorProto]
    service: _containers.RepeatedCompositeFieldContainer[ServiceDescriptorProto]
    extension: _containers.RepeatedCompositeFieldContainer[FieldDescriptorProto]
    options: FileOptions
    source_code_info: SourceCodeInfo
    syntax: str
    edition: Edition
    def __init__(self, name: _Optional[str] = ..., package: _Optional[str] = ..., dependency: _Optional[_Iterable[str]] = ..., public_dependency: _Optional[_Iterable[int]] = ..., weak_dependency: _Optional[_Iterable[int]] = ..., message_type: _Optional[_Iterable[_Union[DescriptorProto, _Mapping]]] = ..., enum_type: _Optional[_Iterable[_Union[EnumDescriptorProto, _Mapping]]] = ..., service: _Optional[_Iterable[_Union[ServiceDescriptorProto, _Mapping]]] = ..., extension: _Optional[_Iterable[_Union[FieldDescriptorProto, _Mapping]]] = ..., options: _Optional[_Union[FileOptions, _Mapping]] = ..., source_code_info: _Optional[_Union[SourceCodeInfo, _Mapping]] = ..., syntax: _Optional[str] = ..., edition: _Optional[_Union[Edition, str]] = ...) -> None: ...

class DescriptorProto(_message.Message):
    __slots__ = ("name", "field", "extension", "nested_type", "enum_type", "extension_range", "oneof_decl", "options", "reserved_range", "reserved_name")
    class ExtensionRange(_message.Message):
        __slots__ = ("start", "end", "options")
        START_FIELD_NUMBER: _ClassVar[int]
        END_FIELD_NUMBER: _ClassVar[int]
        OPTIONS_FIELD_NUMBER: _ClassVar[int]
        start: int
        end: int
        options: ExtensionRangeOptions
        def __init__(self, start: _Optional[int] = ..., end: _Optional[int] = ..., options: _Optional[_Union[ExtensionRangeOptions, _Mapping]] = ...) -> None: ...
    class ReservedRange(_message.Message):
        __slots__ = ("start", "end")
        START_FIELD_NUMBER: _ClassVar[int]
        END_FIELD_NUMBER: _ClassVar[int]
        start: int
        end: int
        def __init__(self, start: _Optional[int] = ..., end: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    NESTED_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENUM_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_RANGE_FIELD_NUMBER: _ClassVar[int]
    ONEOF_DECL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    RESERVED_RANGE_FIELD_NUMBER: _ClassVar[int]
    RESERVED_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    field: _containers.RepeatedCompositeFieldContainer[FieldDescriptorProto]
    extension: _containers.RepeatedCompositeFieldContainer[FieldDescriptorProto]
    nested_type: _containers.RepeatedCompositeFieldContainer[DescriptorProto]
    enum_type: _containers.RepeatedCompositeFieldContainer[EnumDescriptorProto]
    extension_range: _containers.RepeatedCompositeFieldContainer[DescriptorProto.ExtensionRange]
    oneof_decl: _containers.RepeatedCompositeFieldContainer[OneofDescriptorProto]
    options: MessageOptions
    reserved_range: _containers.RepeatedCompositeFieldContainer[DescriptorProto.ReservedRange]
    reserved_name: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., field: _Optional[_Iterable[_Union[FieldDescriptorProto, _Mapping]]] = ..., extension: _Optional[_Iterable[_Union[FieldDescriptorProto, _Mapping]]] = ..., nested_type: _Optional[_Iterable[_Union[DescriptorProto, _Mapping]]] = ..., enum_type: _Optional[_Iterable[_Union[EnumDescriptorProto, _Mapping]]] = ..., extension_range: _Optional[_Iterable[_Union[DescriptorProto.ExtensionRange, _Mapping]]] = ..., oneof_decl: _Optional[_Iterable[_Union[OneofDescriptorProto, _Mapping]]] = ..., options: _Optional[_Union[MessageOptions, _Mapping]] = ..., reserved_range: _Optional[_Iterable[_Union[DescriptorProto.ReservedRange, _Mapping]]] = ..., reserved_name: _Optional[_Iterable[str]] = ...) -> None: ...

class ExtensionRangeOptions(_message.Message):
    __slots__ = ("uninterpreted_option", "declaration", "features", "verification")
    Extensions: _python_message._ExtensionDict
    class VerificationState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DECLARATION: _ClassVar[ExtensionRangeOptions.VerificationState]
        UNVERIFIED: _ClassVar[ExtensionRangeOptions.VerificationState]
    DECLARATION: ExtensionRangeOptions.VerificationState
    UNVERIFIED: ExtensionRangeOptions.VerificationState
    class Declaration(_message.Message):
        __slots__ = ("number", "full_name", "type", "reserved", "repeated")
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        FULL_NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        RESERVED_FIELD_NUMBER: _ClassVar[int]
        REPEATED_FIELD_NUMBER: _ClassVar[int]
        number: int
        full_name: str
        type: str
        reserved: bool
        repeated: bool
        def __init__(self, number: _Optional[int] = ..., full_name: _Optional[str] = ..., type: _Optional[str] = ..., reserved: bool = ..., repeated: bool = ...) -> None: ...
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    DECLARATION_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_FIELD_NUMBER: _ClassVar[int]
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    declaration: _containers.RepeatedCompositeFieldContainer[ExtensionRangeOptions.Declaration]
    features: FeatureSet
    verification: ExtensionRangeOptions.VerificationState
    def __init__(self, uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ..., declaration: _Optional[_Iterable[_Union[ExtensionRangeOptions.Declaration, _Mapping]]] = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., verification: _Optional[_Union[ExtensionRangeOptions.VerificationState, str]] = ...) -> None: ...

class FieldDescriptorProto(_message.Message):
    __slots__ = ("name", "number", "label", "type", "type_name", "extendee", "default_value", "oneof_index", "json_name", "options", "proto3_optional")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TYPE_DOUBLE: _ClassVar[FieldDescriptorProto.Type]
        TYPE_FLOAT: _ClassVar[FieldDescriptorProto.Type]
        TYPE_INT64: _ClassVar[FieldDescriptorProto.Type]
        TYPE_UINT64: _ClassVar[FieldDescriptorProto.Type]
        TYPE_INT32: _ClassVar[FieldDescriptorProto.Type]
        TYPE_FIXED64: _ClassVar[FieldDescriptorProto.Type]
        TYPE_FIXED32: _ClassVar[FieldDescriptorProto.Type]
        TYPE_BOOL: _ClassVar[FieldDescriptorProto.Type]
        TYPE_STRING: _ClassVar[FieldDescriptorProto.Type]
        TYPE_GROUP: _ClassVar[FieldDescriptorProto.Type]
        TYPE_MESSAGE: _ClassVar[FieldDescriptorProto.Type]
        TYPE_BYTES: _ClassVar[FieldDescriptorProto.Type]
        TYPE_UINT32: _ClassVar[FieldDescriptorProto.Type]
        TYPE_ENUM: _ClassVar[FieldDescriptorProto.Type]
        TYPE_SFIXED32: _ClassVar[FieldDescriptorProto.Type]
        TYPE_SFIXED64: _ClassVar[FieldDescriptorProto.Type]
        TYPE_SINT32: _ClassVar[FieldDescriptorProto.Type]
        TYPE_SINT64: _ClassVar[FieldDescriptorProto.Type]
    TYPE_DOUBLE: FieldDescriptorProto.Type
    TYPE_FLOAT: FieldDescriptorProto.Type
    TYPE_INT64: FieldDescriptorProto.Type
    TYPE_UINT64: FieldDescriptorProto.Type
    TYPE_INT32: FieldDescriptorProto.Type
    TYPE_FIXED64: FieldDescriptorProto.Type
    TYPE_FIXED32: FieldDescriptorProto.Type
    TYPE_BOOL: FieldDescriptorProto.Type
    TYPE_STRING: FieldDescriptorProto.Type
    TYPE_GROUP: FieldDescriptorProto.Type
    TYPE_MESSAGE: FieldDescriptorProto.Type
    TYPE_BYTES: FieldDescriptorProto.Type
    TYPE_UINT32: FieldDescriptorProto.Type
    TYPE_ENUM: FieldDescriptorProto.Type
    TYPE_SFIXED32: FieldDescriptorProto.Type
    TYPE_SFIXED64: FieldDescriptorProto.Type
    TYPE_SINT32: FieldDescriptorProto.Type
    TYPE_SINT64: FieldDescriptorProto.Type
    class Label(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        LABEL_OPTIONAL: _ClassVar[FieldDescriptorProto.Label]
        LABEL_REPEATED: _ClassVar[FieldDescriptorProto.Label]
        LABEL_REQUIRED: _ClassVar[FieldDescriptorProto.Label]
    LABEL_OPTIONAL: FieldDescriptorProto.Label
    LABEL_REPEATED: FieldDescriptorProto.Label
    LABEL_REQUIRED: FieldDescriptorProto.Label
    NAME_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    EXTENDEE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_VALUE_FIELD_NUMBER: _ClassVar[int]
    ONEOF_INDEX_FIELD_NUMBER: _ClassVar[int]
    JSON_NAME_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROTO3_OPTIONAL_FIELD_NUMBER: _ClassVar[int]
    name: str
    number: int
    label: FieldDescriptorProto.Label
    type: FieldDescriptorProto.Type
    type_name: str
    extendee: str
    default_value: str
    oneof_index: int
    json_name: str
    options: FieldOptions
    proto3_optional: bool
    def __init__(self, name: _Optional[str] = ..., number: _Optional[int] = ..., label: _Optional[_Union[FieldDescriptorProto.Label, str]] = ..., type: _Optional[_Union[FieldDescriptorProto.Type, str]] = ..., type_name: _Optional[str] = ..., extendee: _Optional[str] = ..., default_value: _Optional[str] = ..., oneof_index: _Optional[int] = ..., json_name: _Optional[str] = ..., options: _Optional[_Union[FieldOptions, _Mapping]] = ..., proto3_optional: bool = ...) -> None: ...

class OneofDescriptorProto(_message.Message):
    __slots__ = ("name", "options")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    options: OneofOptions
    def __init__(self, name: _Optional[str] = ..., options: _Optional[_Union[OneofOptions, _Mapping]] = ...) -> None: ...

class EnumDescriptorProto(_message.Message):
    __slots__ = ("name", "value", "options", "reserved_range", "reserved_name")
    class EnumReservedRange(_message.Message):
        __slots__ = ("start", "end")
        START_FIELD_NUMBER: _ClassVar[int]
        END_FIELD_NUMBER: _ClassVar[int]
        start: int
        end: int
        def __init__(self, start: _Optional[int] = ..., end: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    RESERVED_RANGE_FIELD_NUMBER: _ClassVar[int]
    RESERVED_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: _containers.RepeatedCompositeFieldContainer[EnumValueDescriptorProto]
    options: EnumOptions
    reserved_range: _containers.RepeatedCompositeFieldContainer[EnumDescriptorProto.EnumReservedRange]
    reserved_name: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Iterable[_Union[EnumValueDescriptorProto, _Mapping]]] = ..., options: _Optional[_Union[EnumOptions, _Mapping]] = ..., reserved_range: _Optional[_Iterable[_Union[EnumDescriptorProto.EnumReservedRange, _Mapping]]] = ..., reserved_name: _Optional[_Iterable[str]] = ...) -> None: ...

class EnumValueDescriptorProto(_message.Message):
    __slots__ = ("name", "number", "options")
    NAME_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    number: int
    options: EnumValueOptions
    def __init__(self, name: _Optional[str] = ..., number: _Optional[int] = ..., options: _Optional[_Union[EnumValueOptions, _Mapping]] = ...) -> None: ...

class ServiceDescriptorProto(_message.Message):
    __slots__ = ("name", "method", "options")
    NAME_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    method: _containers.RepeatedCompositeFieldContainer[MethodDescriptorProto]
    options: ServiceOptions
    def __init__(self, name: _Optional[str] = ..., method: _Optional[_Iterable[_Union[MethodDescriptorProto, _Mapping]]] = ..., options: _Optional[_Union[ServiceOptions, _Mapping]] = ...) -> None: ...

class MethodDescriptorProto(_message.Message):
    __slots__ = ("name", "input_type", "output_type", "options", "client_streaming", "server_streaming")
    NAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_TYPE_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TYPE_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STREAMING_FIELD_NUMBER: _ClassVar[int]
    SERVER_STREAMING_FIELD_NUMBER: _ClassVar[int]
    name: str
    input_type: str
    output_type: str
    options: MethodOptions
    client_streaming: bool
    server_streaming: bool
    def __init__(self, name: _Optional[str] = ..., input_type: _Optional[str] = ..., output_type: _Optional[str] = ..., options: _Optional[_Union[MethodOptions, _Mapping]] = ..., client_streaming: bool = ..., server_streaming: bool = ...) -> None: ...

class FileOptions(_message.Message):
    __slots__ = ("java_package", "java_outer_classname", "java_multiple_files", "java_generate_equals_and_hash", "java_string_check_utf8", "optimize_for", "go_package", "cc_generic_services", "java_generic_services", "py_generic_services", "deprecated", "cc_enable_arenas", "objc_class_prefix", "csharp_namespace", "swift_prefix", "php_class_prefix", "php_namespace", "php_metadata_namespace", "ruby_package", "features", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    class OptimizeMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SPEED: _ClassVar[FileOptions.OptimizeMode]
        CODE_SIZE: _ClassVar[FileOptions.OptimizeMode]
        LITE_RUNTIME: _ClassVar[FileOptions.OptimizeMode]
    SPEED: FileOptions.OptimizeMode
    CODE_SIZE: FileOptions.OptimizeMode
    LITE_RUNTIME: FileOptions.OptimizeMode
    JAVA_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    JAVA_OUTER_CLASSNAME_FIELD_NUMBER: _ClassVar[int]
    JAVA_MULTIPLE_FILES_FIELD_NUMBER: _ClassVar[int]
    JAVA_GENERATE_EQUALS_AND_HASH_FIELD_NUMBER: _ClassVar[int]
    JAVA_STRING_CHECK_UTF8_FIELD_NUMBER: _ClassVar[int]
    OPTIMIZE_FOR_FIELD_NUMBER: _ClassVar[int]
    GO_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    CC_GENERIC_SERVICES_FIELD_NUMBER: _ClassVar[int]
    JAVA_GENERIC_SERVICES_FIELD_NUMBER: _ClassVar[int]
    PY_GENERIC_SERVICES_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    CC_ENABLE_ARENAS_FIELD_NUMBER: _ClassVar[int]
    OBJC_CLASS_PREFIX_FIELD_NUMBER: _ClassVar[int]
    CSHARP_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SWIFT_PREFIX_FIELD_NUMBER: _ClassVar[int]
    PHP_CLASS_PREFIX_FIELD_NUMBER: _ClassVar[int]
    PHP_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    PHP_METADATA_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    RUBY_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    java_package: str
    java_outer_classname: str
    java_multiple_files: bool
    java_generate_equals_and_hash: bool
    java_string_check_utf8: bool
    optimize_for: FileOptions.OptimizeMode
    go_package: str
    cc_generic_services: bool
    java_generic_services: bool
    py_generic_services: bool
    deprecated: bool
    cc_enable_arenas: bool
    objc_class_prefix: str
    csharp_namespace: str
    swift_prefix: str
    php_class_prefix: str
    php_namespace: str
    php_metadata_namespace: str
    ruby_package: str
    features: FeatureSet
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, java_package: _Optional[str] = ..., java_outer_classname: _Optional[str] = ..., java_multiple_files: bool = ..., java_generate_equals_and_hash: bool = ..., java_string_check_utf8: bool = ..., optimize_for: _Optional[_Union[FileOptions.OptimizeMode, str]] = ..., go_package: _Optional[str] = ..., cc_generic_services: bool = ..., java_generic_services: bool = ..., py_generic_services: bool = ..., deprecated: bool = ..., cc_enable_arenas: bool = ..., objc_class_prefix: _Optional[str] = ..., csharp_namespace: _Optional[str] = ..., swift_prefix: _Optional[str] = ..., php_class_prefix: _Optional[str] = ..., php_namespace: _Optional[str] = ..., php_metadata_namespace: _Optional[str] = ..., ruby_package: _Optional[str] = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class MessageOptions(_message.Message):
    __slots__ = ("message_set_wire_format", "no_standard_descriptor_accessor", "deprecated", "map_entry", "deprecated_legacy_json_field_conflicts", "features", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    MESSAGE_SET_WIRE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    NO_STANDARD_DESCRIPTOR_ACCESSOR_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    MAP_ENTRY_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_LEGACY_JSON_FIELD_CONFLICTS_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    message_set_wire_format: bool
    no_standard_descriptor_accessor: bool
    deprecated: bool
    map_entry: bool
    deprecated_legacy_json_field_conflicts: bool
    features: FeatureSet
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, message_set_wire_format: bool = ..., no_standard_descriptor_accessor: bool = ..., deprecated: bool = ..., map_entry: bool = ..., deprecated_legacy_json_field_conflicts: bool = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class FieldOptions(_message.Message):
    __slots__ = ("ctype", "packed", "jstype", "lazy", "unverified_lazy", "deprecated", "weak", "debug_redact", "retention", "targets", "edition_defaults", "features", "feature_support", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    class CType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STRING: _ClassVar[FieldOptions.CType]
        CORD: _ClassVar[FieldOptions.CType]
        STRING_PIECE: _ClassVar[FieldOptions.CType]
    STRING: FieldOptions.CType
    CORD: FieldOptions.CType
    STRING_PIECE: FieldOptions.CType
    class JSType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        JS_NORMAL: _ClassVar[FieldOptions.JSType]
        JS_STRING: _ClassVar[FieldOptions.JSType]
        JS_NUMBER: _ClassVar[FieldOptions.JSType]
    JS_NORMAL: FieldOptions.JSType
    JS_STRING: FieldOptions.JSType
    JS_NUMBER: FieldOptions.JSType
    class OptionRetention(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RETENTION_UNKNOWN: _ClassVar[FieldOptions.OptionRetention]
        RETENTION_RUNTIME: _ClassVar[FieldOptions.OptionRetention]
        RETENTION_SOURCE: _ClassVar[FieldOptions.OptionRetention]
    RETENTION_UNKNOWN: FieldOptions.OptionRetention
    RETENTION_RUNTIME: FieldOptions.OptionRetention
    RETENTION_SOURCE: FieldOptions.OptionRetention
    class OptionTargetType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TARGET_TYPE_UNKNOWN: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_FILE: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_EXTENSION_RANGE: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_MESSAGE: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_FIELD: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_ONEOF: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_ENUM: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_ENUM_ENTRY: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_SERVICE: _ClassVar[FieldOptions.OptionTargetType]
        TARGET_TYPE_METHOD: _ClassVar[FieldOptions.OptionTargetType]
    TARGET_TYPE_UNKNOWN: FieldOptions.OptionTargetType
    TARGET_TYPE_FILE: FieldOptions.OptionTargetType
    TARGET_TYPE_EXTENSION_RANGE: FieldOptions.OptionTargetType
    TARGET_TYPE_MESSAGE: FieldOptions.OptionTargetType
    TARGET_TYPE_FIELD: FieldOptions.OptionTargetType
    TARGET_TYPE_ONEOF: FieldOptions.OptionTargetType
    TARGET_TYPE_ENUM: FieldOptions.OptionTargetType
    TARGET_TYPE_ENUM_ENTRY: FieldOptions.OptionTargetType
    TARGET_TYPE_SERVICE: FieldOptions.OptionTargetType
    TARGET_TYPE_METHOD: FieldOptions.OptionTargetType
    class EditionDefault(_message.Message):
        __slots__ = ("edition", "value")
        EDITION_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        edition: Edition
        value: str
        def __init__(self, edition: _Optional[_Union[Edition, str]] = ..., value: _Optional[str] = ...) -> None: ...
    class FeatureSupport(_message.Message):
        __slots__ = ("edition_introduced", "edition_deprecated", "deprecation_warning", "edition_removed")
        EDITION_INTRODUCED_FIELD_NUMBER: _ClassVar[int]
        EDITION_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
        DEPRECATION_WARNING_FIELD_NUMBER: _ClassVar[int]
        EDITION_REMOVED_FIELD_NUMBER: _ClassVar[int]
        edition_introduced: Edition
        edition_deprecated: Edition
        deprecation_warning: str
        edition_removed: Edition
        def __init__(self, edition_introduced: _Optional[_Union[Edition, str]] = ..., edition_deprecated: _Optional[_Union[Edition, str]] = ..., deprecation_warning: _Optional[str] = ..., edition_removed: _Optional[_Union[Edition, str]] = ...) -> None: ...
    CTYPE_FIELD_NUMBER: _ClassVar[int]
    PACKED_FIELD_NUMBER: _ClassVar[int]
    JSTYPE_FIELD_NUMBER: _ClassVar[int]
    LAZY_FIELD_NUMBER: _ClassVar[int]
    UNVERIFIED_LAZY_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    WEAK_FIELD_NUMBER: _ClassVar[int]
    DEBUG_REDACT_FIELD_NUMBER: _ClassVar[int]
    RETENTION_FIELD_NUMBER: _ClassVar[int]
    TARGETS_FIELD_NUMBER: _ClassVar[int]
    EDITION_DEFAULTS_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    FEATURE_SUPPORT_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    ctype: FieldOptions.CType
    packed: bool
    jstype: FieldOptions.JSType
    lazy: bool
    unverified_lazy: bool
    deprecated: bool
    weak: bool
    debug_redact: bool
    retention: FieldOptions.OptionRetention
    targets: _containers.RepeatedScalarFieldContainer[FieldOptions.OptionTargetType]
    edition_defaults: _containers.RepeatedCompositeFieldContainer[FieldOptions.EditionDefault]
    features: FeatureSet
    feature_support: FieldOptions.FeatureSupport
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, ctype: _Optional[_Union[FieldOptions.CType, str]] = ..., packed: bool = ..., jstype: _Optional[_Union[FieldOptions.JSType, str]] = ..., lazy: bool = ..., unverified_lazy: bool = ..., deprecated: bool = ..., weak: bool = ..., debug_redact: bool = ..., retention: _Optional[_Union[FieldOptions.OptionRetention, str]] = ..., targets: _Optional[_Iterable[_Union[FieldOptions.OptionTargetType, str]]] = ..., edition_defaults: _Optional[_Iterable[_Union[FieldOptions.EditionDefault, _Mapping]]] = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., feature_support: _Optional[_Union[FieldOptions.FeatureSupport, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class OneofOptions(_message.Message):
    __slots__ = ("features", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    features: FeatureSet
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, features: _Optional[_Union[FeatureSet, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class EnumOptions(_message.Message):
    __slots__ = ("allow_alias", "deprecated", "deprecated_legacy_json_field_conflicts", "features", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    ALLOW_ALIAS_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_LEGACY_JSON_FIELD_CONFLICTS_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    allow_alias: bool
    deprecated: bool
    deprecated_legacy_json_field_conflicts: bool
    features: FeatureSet
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, allow_alias: bool = ..., deprecated: bool = ..., deprecated_legacy_json_field_conflicts: bool = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class EnumValueOptions(_message.Message):
    __slots__ = ("deprecated", "features", "debug_redact", "feature_support", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    DEBUG_REDACT_FIELD_NUMBER: _ClassVar[int]
    FEATURE_SUPPORT_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    deprecated: bool
    features: FeatureSet
    debug_redact: bool
    feature_support: FieldOptions.FeatureSupport
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, deprecated: bool = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., debug_redact: bool = ..., feature_support: _Optional[_Union[FieldOptions.FeatureSupport, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class ServiceOptions(_message.Message):
    __slots__ = ("features", "deprecated", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    features: FeatureSet
    deprecated: bool
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, features: _Optional[_Union[FeatureSet, _Mapping]] = ..., deprecated: bool = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class MethodOptions(_message.Message):
    __slots__ = ("deprecated", "idempotency_level", "features", "uninterpreted_option")
    Extensions: _python_message._ExtensionDict
    class IdempotencyLevel(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        IDEMPOTENCY_UNKNOWN: _ClassVar[MethodOptions.IdempotencyLevel]
        NO_SIDE_EFFECTS: _ClassVar[MethodOptions.IdempotencyLevel]
        IDEMPOTENT: _ClassVar[MethodOptions.IdempotencyLevel]
    IDEMPOTENCY_UNKNOWN: MethodOptions.IdempotencyLevel
    NO_SIDE_EFFECTS: MethodOptions.IdempotencyLevel
    IDEMPOTENT: MethodOptions.IdempotencyLevel
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    IDEMPOTENCY_LEVEL_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    UNINTERPRETED_OPTION_FIELD_NUMBER: _ClassVar[int]
    deprecated: bool
    idempotency_level: MethodOptions.IdempotencyLevel
    features: FeatureSet
    uninterpreted_option: _containers.RepeatedCompositeFieldContainer[UninterpretedOption]
    def __init__(self, deprecated: bool = ..., idempotency_level: _Optional[_Union[MethodOptions.IdempotencyLevel, str]] = ..., features: _Optional[_Union[FeatureSet, _Mapping]] = ..., uninterpreted_option: _Optional[_Iterable[_Union[UninterpretedOption, _Mapping]]] = ...) -> None: ...

class UninterpretedOption(_message.Message):
    __slots__ = ("name", "identifier_value", "positive_int_value", "negative_int_value", "double_value", "string_value", "aggregate_value")
    class NamePart(_message.Message):
        __slots__ = ("name_part", "is_extension")
        NAME_PART_FIELD_NUMBER: _ClassVar[int]
        IS_EXTENSION_FIELD_NUMBER: _ClassVar[int]
        name_part: str
        is_extension: bool
        def __init__(self, name_part: _Optional[str] = ..., is_extension: bool = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_VALUE_FIELD_NUMBER: _ClassVar[int]
    POSITIVE_INT_VALUE_FIELD_NUMBER: _ClassVar[int]
    NEGATIVE_INT_VALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    AGGREGATE_VALUE_FIELD_NUMBER: _ClassVar[int]
    name: _containers.RepeatedCompositeFieldContainer[UninterpretedOption.NamePart]
    identifier_value: str
    positive_int_value: int
    negative_int_value: int
    double_value: float
    string_value: bytes
    aggregate_value: str
    def __init__(self, name: _Optional[_Iterable[_Union[UninterpretedOption.NamePart, _Mapping]]] = ..., identifier_value: _Optional[str] = ..., positive_int_value: _Optional[int] = ..., negative_int_value: _Optional[int] = ..., double_value: _Optional[float] = ..., string_value: _Optional[bytes] = ..., aggregate_value: _Optional[str] = ...) -> None: ...

class FeatureSet(_message.Message):
    __slots__ = ("field_presence", "enum_type", "repeated_field_encoding", "utf8_validation", "message_encoding", "json_format")
    Extensions: _python_message._ExtensionDict
    class FieldPresence(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FIELD_PRESENCE_UNKNOWN: _ClassVar[FeatureSet.FieldPresence]
        EXPLICIT: _ClassVar[FeatureSet.FieldPresence]
        IMPLICIT: _ClassVar[FeatureSet.FieldPresence]
        LEGACY_REQUIRED: _ClassVar[FeatureSet.FieldPresence]
    FIELD_PRESENCE_UNKNOWN: FeatureSet.FieldPresence
    EXPLICIT: FeatureSet.FieldPresence
    IMPLICIT: FeatureSet.FieldPresence
    LEGACY_REQUIRED: FeatureSet.FieldPresence
    class EnumType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ENUM_TYPE_UNKNOWN: _ClassVar[FeatureSet.EnumType]
        OPEN: _ClassVar[FeatureSet.EnumType]
        CLOSED: _ClassVar[FeatureSet.EnumType]
    ENUM_TYPE_UNKNOWN: FeatureSet.EnumType
    OPEN: FeatureSet.EnumType
    CLOSED: FeatureSet.EnumType
    class RepeatedFieldEncoding(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        REPEATED_FIELD_ENCODING_UNKNOWN: _ClassVar[FeatureSet.RepeatedFieldEncoding]
        PACKED: _ClassVar[FeatureSet.RepeatedFieldEncoding]
        EXPANDED: _ClassVar[FeatureSet.RepeatedFieldEncoding]
    REPEATED_FIELD_ENCODING_UNKNOWN: FeatureSet.RepeatedFieldEncoding
    PACKED: FeatureSet.RepeatedFieldEncoding
    EXPANDED: FeatureSet.RepeatedFieldEncoding
    class Utf8Validation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UTF8_VALIDATION_UNKNOWN: _ClassVar[FeatureSet.Utf8Validation]
        VERIFY: _ClassVar[FeatureSet.Utf8Validation]
        NONE: _ClassVar[FeatureSet.Utf8Validation]
    UTF8_VALIDATION_UNKNOWN: FeatureSet.Utf8Validation
    VERIFY: FeatureSet.Utf8Validation
    NONE: FeatureSet.Utf8Validation
    class MessageEncoding(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MESSAGE_ENCODING_UNKNOWN: _ClassVar[FeatureSet.MessageEncoding]
        LENGTH_PREFIXED: _ClassVar[FeatureSet.MessageEncoding]
        DELIMITED: _ClassVar[FeatureSet.MessageEncoding]
    MESSAGE_ENCODING_UNKNOWN: FeatureSet.MessageEncoding
    LENGTH_PREFIXED: FeatureSet.MessageEncoding
    DELIMITED: FeatureSet.MessageEncoding
    class JsonFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        JSON_FORMAT_UNKNOWN: _ClassVar[FeatureSet.JsonFormat]
        ALLOW: _ClassVar[FeatureSet.JsonFormat]
        LEGACY_BEST_EFFORT: _ClassVar[FeatureSet.JsonFormat]
    JSON_FORMAT_UNKNOWN: FeatureSet.JsonFormat
    ALLOW: FeatureSet.JsonFormat
    LEGACY_BEST_EFFORT: FeatureSet.JsonFormat
    FIELD_PRESENCE_FIELD_NUMBER: _ClassVar[int]
    ENUM_TYPE_FIELD_NUMBER: _ClassVar[int]
    REPEATED_FIELD_ENCODING_FIELD_NUMBER: _ClassVar[int]
    UTF8_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ENCODING_FIELD_NUMBER: _ClassVar[int]
    JSON_FORMAT_FIELD_NUMBER: _ClassVar[int]
    field_presence: FeatureSet.FieldPresence
    enum_type: FeatureSet.EnumType
    repeated_field_encoding: FeatureSet.RepeatedFieldEncoding
    utf8_validation: FeatureSet.Utf8Validation
    message_encoding: FeatureSet.MessageEncoding
    json_format: FeatureSet.JsonFormat
    def __init__(self, field_presence: _Optional[_Union[FeatureSet.FieldPresence, str]] = ..., enum_type: _Optional[_Union[FeatureSet.EnumType, str]] = ..., repeated_field_encoding: _Optional[_Union[FeatureSet.RepeatedFieldEncoding, str]] = ..., utf8_validation: _Optional[_Union[FeatureSet.Utf8Validation, str]] = ..., message_encoding: _Optional[_Union[FeatureSet.MessageEncoding, str]] = ..., json_format: _Optional[_Union[FeatureSet.JsonFormat, str]] = ...) -> None: ...

class FeatureSetDefaults(_message.Message):
    __slots__ = ("defaults", "minimum_edition", "maximum_edition")
    class FeatureSetEditionDefault(_message.Message):
        __slots__ = ("edition", "overridable_features", "fixed_features")
        EDITION_FIELD_NUMBER: _ClassVar[int]
        OVERRIDABLE_FEATURES_FIELD_NUMBER: _ClassVar[int]
        FIXED_FEATURES_FIELD_NUMBER: _ClassVar[int]
        edition: Edition
        overridable_features: FeatureSet
        fixed_features: FeatureSet
        def __init__(self, edition: _Optional[_Union[Edition, str]] = ..., overridable_features: _Optional[_Union[FeatureSet, _Mapping]] = ..., fixed_features: _Optional[_Union[FeatureSet, _Mapping]] = ...) -> None: ...
    DEFAULTS_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_EDITION_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_EDITION_FIELD_NUMBER: _ClassVar[int]
    defaults: _containers.RepeatedCompositeFieldContainer[FeatureSetDefaults.FeatureSetEditionDefault]
    minimum_edition: Edition
    maximum_edition: Edition
    def __init__(self, defaults: _Optional[_Iterable[_Union[FeatureSetDefaults.FeatureSetEditionDefault, _Mapping]]] = ..., minimum_edition: _Optional[_Union[Edition, str]] = ..., maximum_edition: _Optional[_Union[Edition, str]] = ...) -> None: ...

class SourceCodeInfo(_message.Message):
    __slots__ = ("location",)
    Extensions: _python_message._ExtensionDict
    class Location(_message.Message):
        __slots__ = ("path", "span", "leading_comments", "trailing_comments", "leading_detached_comments")
        PATH_FIELD_NUMBER: _ClassVar[int]
        SPAN_FIELD_NUMBER: _ClassVar[int]
        LEADING_COMMENTS_FIELD_NUMBER: _ClassVar[int]
        TRAILING_COMMENTS_FIELD_NUMBER: _ClassVar[int]
        LEADING_DETACHED_COMMENTS_FIELD_NUMBER: _ClassVar[int]
        path: _containers.RepeatedScalarFieldContainer[int]
        span: _containers.RepeatedScalarFieldContainer[int]
        leading_comments: str
        trailing_comments: str
        leading_detached_comments: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, path: _Optional[_Iterable[int]] = ..., span: _Optional[_Iterable[int]] = ..., leading_comments: _Optional[str] = ..., trailing_comments: _Optional[str] = ..., leading_detached_comments: _Optional[_Iterable[str]] = ...) -> None: ...
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    location: _containers.RepeatedCompositeFieldContainer[SourceCodeInfo.Location]
    def __init__(self, location: _Optional[_Iterable[_Union[SourceCodeInfo.Location, _Mapping]]] = ...) -> None: ...

class GeneratedCodeInfo(_message.Message):
    __slots__ = ("annotation",)
    class Annotation(_message.Message):
        __slots__ = ("path", "source_file", "begin", "end", "semantic")
        class Semantic(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            NONE: _ClassVar[GeneratedCodeInfo.Annotation.Semantic]
            SET: _ClassVar[GeneratedCodeInfo.Annotation.Semantic]
            ALIAS: _ClassVar[GeneratedCodeInfo.Annotation.Semantic]
        NONE: GeneratedCodeInfo.Annotation.Semantic
        SET: GeneratedCodeInfo.Annotation.Semantic
        ALIAS: GeneratedCodeInfo.Annotation.Semantic
        PATH_FIELD_NUMBER: _ClassVar[int]
        SOURCE_FILE_FIELD_NUMBER: _ClassVar[int]
        BEGIN_FIELD_NUMBER: _ClassVar[int]
        END_FIELD_NUMBER: _ClassVar[int]
        SEMANTIC_FIELD_NUMBER: _ClassVar[int]
        path: _containers.RepeatedScalarFieldContainer[int]
        source_file: str
        begin: int
        end: int
        semantic: GeneratedCodeInfo.Annotation.Semantic
        def __init__(self, path: _Optional[_Iterable[int]] = ..., source_file: _Optional[str] = ..., begin: _Optional[int] = ..., end: _Optional[int] = ..., semantic: _Optional[_Union[GeneratedCodeInfo.Annotation.Semantic, str]] = ...) -> None: ...
    ANNOTATION_FIELD_NUMBER: _ClassVar[int]
    annotation: _containers.RepeatedCompositeFieldContainer[GeneratedCodeInfo.Annotation]
    def __init__(self, annotation: _Optional[_Iterable[_Union[GeneratedCodeInfo.Annotation, _Mapping]]] = ...) -> None: ...



from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from ai.stigmer.tenancy.organization.v1 import api_pb2 as _api_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Organizations(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.Organization]
    def __init__(self, entries: _Optional[_Iterable[_Union[_api_pb2.Organization, _Mapping]]] = ...) -> None: ...

class OrganizationList(_message.Message):
    __slots__ = ("total_pages", "entries")
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    total_pages: int
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.Organization]
    def __init__(self, total_pages: _Optional[int] = ..., entries: _Optional[_Iterable[_Union[_api_pb2.Organization, _Mapping]]] = ...) -> None: ...

class OrganizationId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class OrganizationExternalLookup(_message.Message):
    __slots__ = ("identity_provider_ref", "external_org_id")
    IDENTITY_PROVIDER_REF_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ORG_ID_FIELD_NUMBER: _ClassVar[int]
    identity_provider_ref: _io_pb2.ApiResourceReference
    external_org_id: str
    def __init__(self, identity_provider_ref: _Optional[_Union[_io_pb2.ApiResourceReference, _Mapping]] = ..., external_org_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/agentic/workflow/v1/enum.proto\x12\x1e\x61i.stigmer.agentic.workflow.v1*\xf6\x01\n\x10WorkflowTaskKind\x12\"\n\x1eworkflow_task_kind_unspecified\x10\x00\x12\x0c\n\x08set_vars\x10\x01\x12\r\n\thttp_call\x10\x02\x12\r\n\tgrpc_call\x10\x03\x12\x11\n\ractivity_call\x10\x04\x12\x0f\n\x0bswitch_case\x10\x05\x12\x0c\n\x08\x66or_each\x10\x06\x12\x08\n\x04\x66ork\x10\x07\x12\r\n\ttry_catch\x10\x08\x12\n\n\x06listen\x10\t\x12\x08\n\x04wait\x10\n\x12\x0f\n\x0braise_error\x10\x0b\x12\x10\n\x0crun_workflow\x10\x0c\x12\x0e\n\nagent_call\x10\rB\xcc\x01\n\"com.ai.stigmer.agentic.workflow.v1B\tEnumProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\x1e\x41i.Stigmer.Agentic.Workflow.V1\xca\x02\x1e\x41i\\Stigmer\\Agentic\\Workflow\\V1\xe2\x02*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\xea\x02\"Ai::Stigmer::Agentic::Workflow::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.agentic.workflow.v1B\tEnumProtoP\001\242\002\004ASAW\252\002\036Ai.Stigmer.Agentic.Workflow.V1\312\002\036Ai\\Stigmer\\Agentic\\Workflow\\V1\342\002*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\352\002\"Ai::Stigmer::Agentic::Workflow::V1'
  _globals['_WORKFLOWTASKKIND']._serialized_start=78
  _globals['_WORKFLOWTASKKIND']._serialized_end=324
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import iam_permission_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_iam__permission__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ai/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto\x12,ai.stigmer.iam.iampolicy.v1.rpcauthorization\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/iam_permission.proto\"\xf1\x02\n\x16RpcAuthorizationConfig\x12\x66\n\npermission\x18\x01 \x01(\x0e\x32\x46.ai.stigmer.iam.iampolicy.v1.rpcauthorization.ApiResourceIamPermissionR\npermission\x12\x64\n\rresource_kind\x18\x02 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x0cresourceKind\x12,\n\x12resource_kind_path\x18\x03 \x01(\tR\x10resourceKindPath\x12\x1d\n\nfield_path\x18\x04 \x01(\tR\tfieldPath\x12\x1b\n\terror_msg\x18\x05 \x01(\tR\x08\x65rrorMsg\x12\x1f\n\x0bresource_id\x18\x06 \x01(\tR\nresourceIdB\x93\x02\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\x07IoProtoP\x01\xa2\x02\x06\x41SIIVR\xaa\x02,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\xca\x02,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\xe2\x02\x38\x41i\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\xea\x02\x31\x41i::Stigmer::Iam::Iampolicy::V1::Rpcauthorizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.rpcauthorization.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\007IoProtoP\001\242\002\006ASIIVR\252\002,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\312\002,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\342\0028Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\352\0021Ai::Stigmer::Iam::Iampolicy::V1::Rpcauthorization'
  _globals['_RPCAUTHORIZATIONCONFIG']._serialized_start=243
  _globals['_RPCAUTHORIZATIONCONFIG']._serialized_end=612
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResourceIamPermission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    unspecified: _ClassVar[ApiResourceIamPermission]
    create: _ClassVar[ApiResourceIamPermission]
    can_delete: _ClassVar[ApiResourceIamPermission]
    can_view: _ClassVar[ApiResourceIamPermission]
    can_edit: _ClassVar[ApiResourceIamPermission]
    login_to_back_office: _ClassVar[ApiResourceIamPermission]
    can_grant_access: _ClassVar[ApiResourceIamPermission]
    can_view_access: _ClassVar[ApiResourceIamPermission]
    owner: _ClassVar[ApiResourceIamPermission]
    member: _ClassVar[ApiResourceIamPermission]
    viewer: _ClassVar[ApiResourceIamPermission]
    identity_account: _ClassVar[ApiResourceIamPermission]
    organization: _ClassVar[ApiResourceIamPermission]
    session: _ClassVar[ApiResourceIamPermission]
    agent: _ClassVar[ApiResourceIamPermission]
    can_create_agent: _ClassVar[ApiResourceIamPermission]
    can_create_workflow: _ClassVar[ApiResourceIamPermission]
    can_create_session: _ClassVar[ApiResourceIamPermission]
    can_create_execution_in: _ClassVar[ApiResourceIamPermission]
    can_create_instance: _ClassVar[ApiResourceIamPermission]
    can_create_skill: _ClassVar[ApiResourceIamPermission]
    can_create_project: _ClassVar[ApiResourceIamPermission]
    can_create_idp: _ClassVar[ApiResourceIamPermission]
    can_create_environment: _ClassVar[ApiResourceIamPermission]
    can_execute: _ClassVar[ApiResourceIamPermission]
    can_read_secrets: _ClassVar[ApiResourceIamPermission]
    can_bootstrap_iam: _ClassVar[ApiResourceIamPermission]
    can_manage_identity_accounts: _ClassVar[ApiResourceIamPermission]
    can_update_execution_status: _ClassVar[ApiResourceIamPermission]
unspecified: ApiResourceIamPermission
create: ApiResourceIamPermission
can_delete: ApiResourceIamPermission
can_view: ApiResourceIamPermission
can_edit: ApiResourceIamPermission
login_to_back_office: ApiResourceIamPermission
can_grant_access: ApiResourceIamPermission
can_view_access: ApiResourceIamPermission
owner: ApiResourceIamPermission
member: ApiResourceIamPermission
viewer: ApiResourceIamPermission
identity_account: ApiResourceIamPermission
organization: ApiResourceIamPermission
session: ApiResourceIamPermission
agent: ApiResourceIamPermission
can_create_agent: ApiResourceIamPermission
can_create_workflow: ApiResourceIamPermission
can_create_session: ApiResourceIamPermission
can_create_execution_in: ApiResourceIamPermission
can_create_instance: ApiResourceIamPermission
can_create_skill: ApiResourceIamPermission
can_create_project: ApiResourceIamPermission
can_create_idp: ApiResourceIamPermission
can_create_environment: ApiResourceIamPermission
can_execute: ApiResourceIamPermission
can_read_secrets: ApiResourceIamPermission
can_bootstrap_iam: ApiResourceIamPermission
can_manage_identity_accounts: ApiResourceIamPermission
can_update_execution_status: ApiResourceIamPermission



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/organization/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/organization/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from ai.stigmer.tenancy.organization.v1 import api_pb2 as ai_dot_stigmer_dot_tenancy_dot_organization_dot_v1_dot_api__pb2
from ai.stigmer.tenancy.organization.v1 import io_pb2 as ai_dot_stigmer_dot_tenancy_dot_organization_dot_v1_dot_io__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ai/stigmer/tenancy/organization/v1/query.proto\x12\"ai.stigmer.tenancy.organization.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a,ai/stigmer/tenancy/organization/v1/api.proto\x1a+ai/stigmer/tenancy/organization/v1/io.proto\x1a\x1bgoogle/protobuf/empty.proto2\xb9\x04\n\x1bOrganizationQueryController\x12\x9f\x01\n\x03get\x12\x32.ai.stigmer.tenancy.organization.v1.OrganizationId\x1a\x30.ai.stigmer.tenancy.organization.v1.Organization\"2\xc2\xb8\x18.\x08\x03\x10\x1e\"\x05value*!unauthorized to view organization\x12{\n\x04\x66ind\x12\x37.ai.stigmer.commons.apiresource.FindApiResourcesRequest\x1a\x34.ai.stigmer.tenancy.organization.v1.OrganizationList\"\x04\xd0\xb8\x18\x01\x12\x66\n\x13\x66indMyOrganizations\x12\x16.google.protobuf.Empty\x1a\x31.ai.stigmer.tenancy.organization.v1.Organizations\"\x04\xd0\xb8\x18\x01\x12\x8c\x01\n\x12getByExternalOrgId\x12>.ai.stigmer.tenancy.organization.v1.OrganizationExternalLookup\x1a\x30.ai.stigmer.tenancy.organization.v1.Organization\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+\x1e\x42\xe1\x01\n&com.ai.stigmer.tenancy.organization.v1B\nQueryProtoP\x01\xa2\x02\x04\x41STO\xaa\x02\"Ai.Stigmer.Tenancy.Organization.V1\xca\x02\"Ai\\Stigmer\\Tenancy\\Organization\\V1\xe2\x02.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Tenancy::Organization::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.organization.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.tenancy.organization.v1B\nQueryProtoP\001\242\002\004ASTO\252\002\"Ai.Stigmer.Tenancy.Organization.V1\312\002\"Ai\\Stigmer\\Tenancy\\Organization\\V1\342\002.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\352\002&Ai::Stigmer::Tenancy::Organization::V1'
  _globals['_ORGANIZATIONQUERYCONTROLLER']._loaded_options = None
  _globals['_ORGANIZATIONQUERYCONTROLLER']._serialized_options = b'\240\377+\036'
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030.\010\003\020\036\"\005value*!unauthorized to view organization'
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['find']._loaded_options = None
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['find']._serialized_options = b'\320\270\030\001'
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['findMyOrganizations']._loaded_options = None
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['findMyOrganizations']._serialized_options = b'\320\270\030\001'
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['getByExternalOrgId']._loaded_options = None
  _globals['_ORGANIZATIONQUERYCONTROLLER'].methods_by_name['getByExternalOrgId']._serialized_options = b'\320\270\030\001'
  _globals['_ORGANIZATIONQUERYCONTROLLER']._serialized_start=373
  _globals['_ORGANIZATIONQUERYCONTROLLER']._serialized_end=942
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/rpc/pagination.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/rpc/pagination.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/commons/rpc/pagination.proto\x12\x16\x61i.stigmer.commons.rpc\"0\n\x08PageInfo\x12\x10\n\x03num\x18\x01 \x01(\x05R\x03num\x12\x12\n\x04size\x18\x02 \x01(\x05R\x04size\"C\n\x0eGooglePageInfo\x12\x1d\n\npage_token\x18\x01 \x01(\tR\tpageToken\x12\x12\n\x04size\x18\x02 \x01(\x05R\x04sizeB\xa9\x01\n\x1a\x63om.ai.stigmer.commons.rpcB\x0fPaginationProtoP\x01\xa2\x02\x04\x41SCR\xaa\x02\x16\x41i.Stigmer.Commons.Rpc\xca\x02\x16\x41i\\Stigmer\\Commons\\Rpc\xe2\x02\"Ai\\Stigmer\\Commons\\Rpc\\GPBMetadata\xea\x02\x19\x41i::Stigmer::Commons::Rpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.rpc.pagination_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ai.stigmer.commons.rpcB\017PaginationProtoP\001\242\002\004ASCR\252\002\026Ai.Stigmer.Commons.Rpc\312\002\026Ai\\Stigmer\\Commons\\Rpc\342\002\"Ai\\Stigmer\\Commons\\Rpc\\GPBMetadata\352\002\031Ai::Stigmer::Commons::Rpc'
  _globals['_PAGEINFO']._serialized_start=67
  _globals['_PAGEINFO']._serialized_end=115
  _globals['_GOOGLEPAGEINFO']._serialized_start=117
  _globals['_GOOGLEPAGEINFO']._serialized_end=184
# @@protoc_insertion_point(module_scope)
